@@ -756,7 +756,11 @@ def get_docs_query(object_id: str, page: int = 1) -> str:
         GraphQL query string
     """
     query = """query {
-        docs (object_ids: %s, page: %s) {
+        complexity {
+            query
+            after
+        }
+        docs (object_ids: %s) {
             id
             created_at
             created_by {
@@ -773,7 +777,7 @@ def get_docs_query(object_id: str, page: int = 1) -> str:
             workspace_id
             object_id
             settings
-            blocks {
+            blocks (page: %s) {
                 type
                 content
                 position
